@@ -2,7 +2,7 @@ from typing import Any
 
 import pytest
 
-from sql_tstring import RewritingValue, sql, sql_context
+from sql_tstring import RewritingValue, sql, sql_context, t
 
 TZ = "uk"
 
@@ -25,6 +25,11 @@ TZ = "uk"
             "SELECT x FROM y WHERE x = ANY(?)",
             [2],
         ),
+        (
+            "SELECT x FROM y JOIN z ON u = {val}",
+            "SELECT x FROM y JOIN z ON u = ?",
+            [2],
+        ),
         (
             "UPDATE x SET x = {val}",
             "UPDATE x SET x = ?",
@@ -45,6 +50,11 @@ TZ = "uk"
             "SELECT x FROM y ORDER BY ARRAY_POSITION(? , x)",
             [2],
         ),
+        (
+            "SELECT x FROM y WHERE x LIKE '%{col}'",
+            "SELECT x FROM y WHERE x LIKE ?",
+            ["%col"],
+        ),
         (
             "INSERT INTO y (x) VALUES (2) ON CONFLICT DO UPDATE SET x = {val}",
             "INSERT INTO y (x) VALUES (2) ON CONFLICT DO UPDATE SET x = ?",
@@ -73,11 +83,26 @@ def test_placeholders(query: str, expected_query: str, expected_values: list[Any
             "SELECT x FROM y WHERE x = 2",
             [],
         ),
+        (
+            "SELECT x FROM y WHERE x = 2 AND (u = {val} OR v = 1)",
+            "SELECT x FROM y WHERE x = 2 AND (v = 1)",
+            [],
+        ),
+        (
+            "SELECT x FROM y WHERE x = 2 AND (v = 1 OR u = {val})",
+            "SELECT x FROM y WHERE x = 2 AND (v = 1)",
+            [],
+        ),
         (
             "SELECT x FROM y WHERE x = {val} AND (v = 1 OR u = 2)",
             "SELECT x FROM y WHERE (v = 1 OR u = 2)",
             [],
         ),
+        (
+            "SELECT x FROM y WHERE x = 2 AND (v = {val} OR u = {val})",
+            "SELECT x FROM y WHERE x = 2",
+            [],
+        ),
         (
             "SELECT x FROM y JOIN z ON u = {val}",
             "SELECT x FROM y JOIN z",
@@ -93,6 +118,11 @@ def test_placeholders(query: str, expected_query: str, expected_values: list[Any
             "SELECT x FROM y",
             [],
         ),
+        (
+            "SELECT x FROM y WHERE x LIKE '%{val}'",
+            "SELECT x FROM y",
+            [],
+        ),
         (
             "UPDATE y SET x = {val}, u = 2",
             "UPDATE y SET u = 2",
@@ -148,3 +178,11 @@ def test_is_null(query: str, expected_query: str, expected_values: list[Any]) ->
 def test_is_not_null(query: str, expected_query: str, expected_values: list[Any]) -> None:
     val = RewritingValue.IS_NOT_NULL
     assert (expected_query, expected_values) == sql(query, locals())
+
+
+def test_nested() -> None:
+    a = "a"
+    inner = t("x = {a}", locals())
+    query, values = sql("SELECT x FROM y WHERE {inner}", locals())
+    assert query == "SELECT x FROM y WHERE x = ?"
+    assert values == ["a"]
